| Title: | Maryland State Department of Education Data |
|---|---|
| Description: | The marylandedu package provides access to selected datasets from the Maryland State Department of Education (MSDE) that have been standardized to better support year-by-year analysis and visualization. |
| Authors: | Eli Pousson [aut, cre, cph] (ORCID: <https://orcid.org/0000-0001-8280-1706>) |
| Maintainer: | Eli Pousson <[email protected]> |
| License: | CC0 |
| Version: | 0.1.0 |
| Built: | 2026-05-09 07:24:36 UTC |
| Source: | https://github.com/elipousson/marylandedu |
A data frame that can be used as a crosswalk between Maryland Local School System (LSS) names and numbers and county-level identifiers from the U.S. Census Bureau.
lss_county_xwalklss_county_xwalk
A data frame with 25 rows and 7 variables:
lss_numberLocal school system (LSS) number as integer.
lss_nameLocal school system (LSS) names.
countyfpCounty FIPS code.
countynsCounty GNIS code.
geoidUnique county FIPS code (concatenation of state and county FIPS codes).
county_nameCounty name. Equivalent to namelsad column from
mapmaryland::md_counties which is a concatenated variable length
geographic area name and legal/statistical area description (LSAD)
regionRegion of the state.
Combined data from XLS and XLSX format NCES directory files downloaded from the MSDE Data Downloads website. The school name field has been corrected for consistency and accuracy across years and capitalization of the city and address fields have been standardized (previously used all upper case for both prior to 2010). A grade span value is filled in for older records where grade span was stored in the school type column.
md_nces_directorymd_nces_directory
A data frame with 33,000 rows and 14 variables:
yearSchool year
school_numberSchool number
school_nameSchool name
school_typeSchool type
addressSchool address
cityCity
stateState
zipZip code
phoneSchool phone number
nces_numberNCES Number
create_dateRecord creation date
grade_spanGrade span (grade band)
lss_nameLSS name
lss_numberLSS number
Last updated 2025-10-10.
Attendance data from the Maryland State Department of Education (MSDE). The
original CSV data files downloaded from MSDE are available in the
data-raw/extdata folder on the GitHub repo for the package. Any percent
variables with a value of 95 percent should be interpreted as equivalent at
or above 95 percent. Any percent variables with a value of 5 percent should
be interpreted as equivalent to at or below 5 percent. Chronic absenteeism
data is not available prior to 2018 when the federal Every Student Succeeds
Act (passed in 2015) went into effect and Maryland began to include the
chronic absenteeism rate in the state's annual academic report cards.
Variable definitions are based on the definitions from the MSDE website.
msde_attendancemsde_attendance
A data frame with 38,808 rows and 18 variables:
yearSchool year or academic year, e.g. 2019 for 2019-2020 school year
school_numberSchool number (0 indicates all schools)
school_nameSchool name
grade_rangeGrade range used for attendance details.
attend_rate_pctAttendance rate as defined as the average daily attendance rate of students in the school and grade band, including special education students
days_attended_countTotal number of students in attendance from the first day of school through April 13th
days_member_countTotal number of students registered to attend from the first day of school through April 13th
fewer_5_pctPercent of students absentee rate is the percentage of students absent from school for five or fewer days between the first day of the school year and the last day of the school year
fewer_5_countCount of students absentee rate is the percentage of students absent from school for five or fewer days between the first day of the school year and the last day of the school year
more_20_pctPercent of students absentee rate is the percentage of students absent from school for twenty or more days between the first day of the school year and the last day of the school year
more_20_countNumber of students absentee rate is the percentage of students absent from school for twenty or more days between the first day of the school year and the last day of the school year
more_90_member_countNumber of students with an attendance rate of 90 percent or more
chronic_absentee_countNumber of students expected to attend school for at least 10 days who were absent 10 percent or more of the school days while enrolled at that school
chronic_absentee_denomNumber of students who are expected to attend school for at least 10 days in the school year
chronic_absentee_pctChronic absenteeism rate as defined as the percent of students expected to attend school for at least 10 days who were absent 10 percent or more of the school days while enrolled at that school
date_createdDate record created.
lss_numberLocal school system (LSS) number as integer. NA is used in place of a LSS number for statewide data. Older LEA numbers are combined with LSS numbers in this dataset.
lss_nameLocal school system (LSS) names (typically same as county name). "State" is used in place of a LSS name for statewide data. Older LEA names are combined with LSS names in this dataset.
Last updated 2025-10-10.
Enrollment data from the Maryland State Department of Education (MSDE). The
original CSV data files downloaded from MSDE are available in the
data-raw/extdata folder on the GitHub repo for the package. The number of enrolled students includes ungraded
special education and pre-kindergarten students. Grades coded as
"Prekindergarten Age 4" in the MSDE data have been re-coded as
"Prekindergarten" to facilitate comparison across years. LEA Names coded as
"Baltimore City - Edison" have been re-coded as "Baltimore City", "Seed
School LEA" as "SEED", and "All Public Schools" as "State". Variable
definitions are based on the definitions from the MSDE website.
msde_enrollmentmsde_enrollment
A data frame with 274,455 rows and 10 variables:
yearSchool or academic year for enrollment count, e.g. 2019 data is from the start of the 2019-2020 school year.
school_numberSchool number as integer (0 indicates all schools)
school_nameSchool name
enrolled_countNumber of students registered to attend the school at the start of the year in the grade or grade range as integer. Typically enrollment count is as of September 30.
gradeGrades from Prekindergarden (PK) to Grade 12
grade_rangeall elementary school Grades, all middle school grades, all high school grades, or all grades (total enrollment). May also be used as a label for grade.
raceRace/ethnicity. Enrollment by race/ethnicity is only available across all grades for years since 2020. "All" is used for data prior to 2020.
date_createdDate record created.
lss_numberLocal school system (LSS) number as integer. NA is used in place of a LSS number for statewide data. Older LEA numbers are combined with LSS numbers in this dataset.
lss_nameLocal school system (LSS) names (typically same as county name). "State" is used in place of a LSS name for statewide data. Older LEA names are combined with LSS names in this dataset.
Last updated 2025-10-10.
Student mobility data from the Maryland State Department of Education (MSDE).
The original CSV data files downloaded from MSDE are available in the
data-raw/extdata folder on the GitHub repo for the package. Mobility refers
to the movement of students from one school to another during the school
year. Three types of mobility are calculated using student entrants and
student withdrawals: Total student mobility, entry mobility, and exit
mobility. Student mobility is the percentage of students that either enter or
withdraw from a school during the school year. To calculate student mobility,
the number of entrants is added to the number of withdrawals and that sum is
divided by the average daily student enrollment.
msde_student_mobilitymsde_student_mobility
A data frame with 36,994 rows and 14 variables:
yearSchool or academic year for enrollment count, e.g. 2019 data is from the start of the 2019-2020 school year.
school_numberSchool number as integer (0 indicates all schools)
school_nameSchool name
school_typeSchool type (e.g. Elementary, Middle, High)
mobile_pctStudent total mobility rate
entry_pctStudent entry mobility rate
exit_pctStudent exit mobility rate
mobile_countSudent entry and exit count
entry_countStudent entry count
exit_countStudent exit count
avg_enrolled_countAverage daily student enrollment.
date_createdDate record created.
lss_numberLocal school system (LSS) number as integer. NA is used in place of a LSS number for statewide data. Older LEA numbers are combined with LSS numbers in this dataset.
lss_nameLocal school system (LSS) names (typically same as county name). "State" is used in place of a LSS name for statewide data. Older LEA names are combined with LSS names in this dataset.
Last updated 2025-10-10.